@@ -164,6 +164,8 @@ namespace anyks {
 			mutable data_t data;
 			// Параметры расчёта
 			mutable param_t param;
+			// Список удалённых слов
+			mutable std::set <size_t> delwords;
 			// Блок шагов (список дочерних грамм для текущей n-граммы)
 			mutable std::map <u_short, list <data_t *>> ngrams;
 		private:
@@ -218,17 +220,17 @@ namespace anyks {
 			 */
 			const bool isStart(const size_t idw) const noexcept;
 			/**
-			 * isWeight Метод проверки на валидность веса
-			 * @param weight вес для проверки
-			 * @return       результат проверки
-			 */
-			const bool isWeight(const double weight) const noexcept;
-			/**
-			 * isWeights Метод проверки существования дочерних n-грамм
+			 * isWord Метод проверки на валидность слова
 			 * @param ngram контекст для проверки
 			 * @return      результат проверки
 			 */
-			const bool isWeights(const data_t * ngram) const noexcept;
+			const bool isWord(const data_t * ngram) const noexcept;
+			/**
+			 * isWords Метод проверки существования дочерних n-грамм
+			 * @param ngram контекст для проверки
+			 * @return      результат проверки
+			 */
+			const bool isWords(const data_t * ngram) const noexcept;
 			/**
 			 * isOption Метод проверки наличия опции
 			 * @param option опция для проверки
@@ -277,6 +279,13 @@ namespace anyks {
 			 * @param denominator разность частот отката n-грамм
 			 */
 			const bool compute(data_t * ngram, const u_short gram, double & numerator, double & denominator) const noexcept;
+		protected:
+			/**
+			 * get Метод извлечения списка n-грамм указанного размера
+			 * @param gram размер n-граммы список грамм которой нужно извлечь
+			 * @return     указатель на список запрашиваемых n-грамм
+			 */
+			list <data_t *> * get(const u_short gram) const noexcept;
 		protected:
 			/**
 			 * contextFn Метод получения контекста
@@ -313,12 +322,6 @@ namespace anyks {
 			 * @param uppers список регистров слова
 			 */
 			void uniUppers(multimap <size_t, size_t> & uppers) const noexcept;
-			/**
-			 * get Метод извлечения списка n-грамм указанного размера
-			 * @param gram   размер n-граммы список грамм которой нужно извлечь
-			 * @param ngrams указатель на список запрашиваемых n-грамм
-			 */
-			void get(const u_short gram, list <data_t *> * ngrams = nullptr) const noexcept;
 			/**
 			 * sequence Метод извлечения правильной последовательности, игнорирования <unk> токена
 			 * @param seq      последовательность для обработки
