@@ -100,14 +100,14 @@ namespace anyks {
 			// Определяем длину шифрования по умолчанию
 			types_t aeslen = types_t::aes128;
 		private:
-			// Позиция raw данных в файле
-			long rawpos = -1;
 			// Устанавливаем количество раундов
 			int roundsAES = 5;
 			// Модуль вектора
 			size_t modulus = 0;
 			// Адрес начала данных
 			size_t address = 0;
+			// Позиция raw данных в файле
+			uintmax_t rawpos = 0;
 		private:
 			// Заголовок файла
 			const char * header = HEADER;
@@ -124,9 +124,9 @@ namespace anyks {
 			 * @return       результат операции (количество записанных байт)
 			 */
 			template <typename Value>
-			static const int setval(const size_t idw, long & rawpos, map <size_t, size_t> & keys, ofstream & file, const Value value) noexcept {
+			static const uintmax_t setval(const size_t idw, uintmax_t & rawpos, map <size_t, size_t> & keys, ofstream & file, const Value value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if((idw > 0) && file.is_open()){
 					// Размер записываемых данных
@@ -158,9 +158,9 @@ namespace anyks {
 			 * @return       результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			static const int setdat(const size_t idw, long & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value, const string & md5 = "") noexcept {
+			static const uintmax_t setdat(const size_t idw, uintmax_t & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value, const string & md5 = "") noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if((idw > 0) && file.is_open()){
 					// Размер записываемых данных
@@ -201,15 +201,17 @@ namespace anyks {
 			 * @return       результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			static const int setvals(const size_t idw, long & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value) noexcept {
+			static const uintmax_t setvals(const size_t idw, uintmax_t & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if((idw > 0) && file.is_open()){
 					// Количество записей в списке
 					const size_t count = value.size();
 					// Общее количество записанных данных
 					size_t size = sizeof(count);
+					// Полученное значение
+					typename Container::value_type val;
 					// Получаем бинарные данные размера записываемых данных
 					const char * bin = reinterpret_cast <const char *> (&count);
 					// Выполняем запись в файл количество записей
@@ -217,7 +219,7 @@ namespace anyks {
 					// Переходим по всему списку записей
 					for(auto it = value.cbegin(); it != value.cend(); ++it){
 						// Получаем значение
-						typename Container::value_type val = (* it);
+						val = (* it);
 						// Получаем бинарные данные размера записываемых данных
 						const char * bin = reinterpret_cast <const char *> (&val);
 						// Выполняем запись в файл каждое значение
@@ -247,11 +249,13 @@ namespace anyks {
 			 * @return       результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			static const int setstrs(const size_t idw, long & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value) noexcept {
+			static const uintmax_t setstrs(const size_t idw, uintmax_t & rawpos, map <size_t, size_t> & keys, ofstream & file, const Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if((idw > 0) && file.is_open()){
+					// Размер записываемых данных
+					size_t length = 0;
 					// Количество записей в списке
 					const size_t count = value.size();
 					// Общее количество записанных данных
@@ -263,7 +267,7 @@ namespace anyks {
 					// Переходим по всему списку записей
 					for(auto it = value.cbegin(); it != value.cend(); ++it){
 						// Размер записываемых данных
-						const size_t length = it->size();
+						length = it->size();
 						// Получаем бинарные данные размера записываемых данных
 						const char * bin = reinterpret_cast <const char *> (&length);
 						// Выполняем запись в файл размер строки
@@ -293,9 +297,9 @@ namespace anyks {
 			 * @return      результат операции (количество записанных байт)
 			 */
 			template <typename Value>
-			static const int getval(const size_t pos, ifstream & file, Value & value) noexcept {
+			static const uintmax_t getval(const size_t pos, ifstream & file, Value & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если файл открыт удачно
 				if(file.is_open()){
 					// Перемещаемся в указанную позицию файла
@@ -317,9 +321,9 @@ namespace anyks {
 			 * @return      результат операции (количество прочитанных байт)
 			 */
 			template <class Container>
-			static const int getdat(const size_t pos, ifstream & file, Container & value, string & md5) noexcept {
+			static const uintmax_t getdat(const size_t pos, ifstream & file, Container & value, string & md5) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если файл открыт удачно
 				if(file.is_open()){
 					// Размер записываемых данных
@@ -364,9 +368,9 @@ namespace anyks {
 			 * @return      результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			static const int getvals(const size_t pos, ifstream & file, Container & value) noexcept {
+			static const uintmax_t getvals(const size_t pos, ifstream & file, Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если файл открыт удачно
 				if(file.is_open()){
 					// Количество записей в списке
@@ -405,9 +409,9 @@ namespace anyks {
 			 * @return       результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			static const int getstrs(const size_t pos, ifstream & file, Container & value) noexcept {
+			static const uintmax_t getstrs(const size_t pos, ifstream & file, Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если файл открыт удачно
 				if(file.is_open()){
 					// Количество записей в списке
@@ -446,7 +450,7 @@ namespace anyks {
 									// Увеличиваем количество прочитанных байт
 									result += (length + sizeof(length));
 								// Если происходит ошибка то игнорируем её
-								} catch(const bad_alloc&) {
+								} catch(const bad_alloc &) {
 									// Выходим из приложения
 									exit(EXIT_FAILURE);
 								}
@@ -476,7 +480,7 @@ namespace anyks {
 			 */
 			void close() noexcept {
 				// Обнуляем последнюю позицию в файле
-				this->rawpos = -1;
+				this->rawpos = 0;
 				// Если файл открыт, закрываем его
 				if(this->ifs.is_open()) this->ifs.close();
 				// Если файл открыт, закрываем его
@@ -506,11 +510,11 @@ namespace anyks {
 							// Если файл открыт на запись
 							if(this->ofs.is_open()) this->close();
 							// Если файл существует
-							if((this->rawpos == -1) && !this->isFile(filename)) this->rawpos = 0;
+							if(!this->isFile(filename)) this->rawpos = 0;
 							// Открываем файл на запись
 							this->ofs.open(filename.c_str(), ios::binary);
 							// Если позиция не определена
-							if(this->rawpos == -1){
+							if(this->rawpos == 0){
 								// Перемещаемся в конец файла
 								this->ofs.seekp(0, this->ofs.end);
 								// Определяем размер файла
@@ -640,7 +644,7 @@ namespace anyks {
 					// Сообщаем что всё удачно
 					return true;
 				// Если происходит ошибка то игнорируем её
-				} catch(const bad_alloc&) {
+				} catch(const bad_alloc &) {
 					// Выходим из приложения
 					exit(EXIT_FAILURE);
 				}
@@ -708,6 +712,8 @@ namespace anyks {
 						this->initAES();
 						// Экранируем возможность ошибки памяти
 						try {
+							// Максимальный размер считываемых данных
+							int chunk = 0;
 							// Размер буфера полученных данных
 							size_t count = 0;
 							// Определяем размер данных для считывания
@@ -719,7 +725,7 @@ namespace anyks {
 							// Выполняем извлечение оставшихся данных
 							do {
 								// Максимальный размер считываемых данных
-								int chunk = (len > CHUNKSIZE ? CHUNKSIZE : len);
+								chunk = (len > CHUNKSIZE ? CHUNKSIZE : len);
 								// Выполняем сжатие данных
 								AES_cfb128_encrypt(input + count, output + count, chunk, &this->aesKey, this->stateAES.ivec, &this->stateAES.num, AES_ENCRYPT);
 								// Увеличиваем смещение
@@ -732,7 +738,7 @@ namespace anyks {
 							// Очищаем буфер
 							delete [] output;
 						// Если происходит ошибка то игнорируем её
-						} catch(const bad_alloc&) {
+						} catch(const bad_alloc &) {
 							// Выходим из приложения
 							exit(EXIT_FAILURE);
 						}
@@ -759,6 +765,8 @@ namespace anyks {
 						this->initAES();
 						// Экранируем возможность ошибки памяти
 						try {
+							// Максимальный размер считываемых данных
+							int chunk = 0;
 							// Размер буфера полученных данных
 							size_t count = 0;
 							// Определяем размер данных для считывания
@@ -770,7 +778,7 @@ namespace anyks {
 							// Выполняем извлечение оставшихся данных
 							do {
 								// Максимальный размер считываемых данных
-								int chunk = (len > CHUNKSIZE ? CHUNKSIZE : len);
+								chunk = (len > CHUNKSIZE ? CHUNKSIZE : len);
 								// Выполняем сжатие данных
 								AES_cfb128_encrypt(input + count, output + count, chunk, &this->aesKey, this->stateAES.ivec, &this->stateAES.num, AES_DECRYPT);
 								// Увеличиваем смещение
@@ -783,7 +791,7 @@ namespace anyks {
 							// Очищаем буфер
 							delete [] output;
 						// Если происходит ошибка то игнорируем её
-						} catch(const bad_alloc&) {
+						} catch(const bad_alloc &) {
 							// Выходим из приложения
 							exit(EXIT_FAILURE);
 						}
@@ -814,8 +822,10 @@ namespace anyks {
 					uint8_t outbuff[CHUNKSIZE];
 					// Если поток инициализировать не удалось, выходим
 					if(deflateInit2(&zs, Z_DEFAULT_COMPRESSION, Z_DEFLATED, MOD_GZIP_ZLIB_WINDOWSIZE + 16, MOD_GZIP_ZLIB_CFACTOR, Z_DEFAULT_STRATEGY) == Z_OK){
-						// Смещение в буфере
-						size_t offset = 0;
+						// Количество оставшихся байт
+						uint32_t nbytes = 0;
+						// Смещение в буфере и размеры доанных
+						size_t offset = 0, count = 0, avail = 0;
 						// Переменная сброса данных
 						int flush = Z_NO_FLUSH;
 						do {
@@ -824,9 +834,9 @@ namespace anyks {
 							// Заполняем нулями буфер исходящих данных
 							memset(outbuff, 0, sizeof(outbuff));
 							// Получаем размер доступных данных
-							const size_t count = (size - offset);
+							count = (size - offset);
 							// Высчитываем количество доступных данных
-							const size_t avail = (count > size_t(CHUNKSIZE) ? CHUNKSIZE : count);
+							avail = (count > size_t(CHUNKSIZE) ? CHUNKSIZE : count);
 							// Устанавливаем количество доступных данных
 							zs.avail_in = avail;
 							// Копируем в буфер данные для шифрования
@@ -843,7 +853,7 @@ namespace anyks {
 								// Выполняем шифрование данных
 								deflate(&zs, flush);
 								// Получаем количество оставшихся байт
-								const uint32_t nbytes = (CHUNKSIZE - zs.avail_out);
+								nbytes = (CHUNKSIZE - zs.avail_out);
 								// Добавляем оставшиеся данные в список
 								result.insert(result.end(), outbuff, outbuff + nbytes);
 							// Если все данные уже сжаты
@@ -880,8 +890,10 @@ namespace anyks {
 					uint8_t outbuff[CHUNKSIZE];
 					// Если поток инициализировать не удалось, выходим
 					if(inflateInit2(&zs, MOD_GZIP_ZLIB_WINDOWSIZE + 16) == Z_OK){
-						// Смещение в буфере
-						size_t offset = 0;
+						// Количество оставшихся байт
+						uint32_t nbytes = 0;
+						// Смещение в буфере и размеры доанных
+						size_t offset = 0, count = 0, avail = 0;
 						// Переменная сброса данных
 						int flush = Z_NO_FLUSH;
 						do {
@@ -890,9 +902,9 @@ namespace anyks {
 							// Заполняем нулями буфер исходящих данных
 							memset(outbuff, 0, sizeof(outbuff));
 							// Получаем размер доступных данных
-							const size_t count = (size - offset);
+							count = (size - offset);
 							// Высчитываем количество доступных данных
-							const size_t avail = (count > size_t(CHUNKSIZE) ? CHUNKSIZE : count);
+							avail = (count > size_t(CHUNKSIZE) ? CHUNKSIZE : count);
 							// Устанавливаем количество доступных данных
 							zs.avail_in = avail;
 							// Если доступных данных нет
@@ -920,7 +932,7 @@ namespace anyks {
 									return result;
 								}
 								// Получаем количество оставшихся байт
-								const uint32_t nbytes = (CHUNKSIZE - zs.avail_out);
+								nbytes = (CHUNKSIZE - zs.avail_out);
 								// Добавляем оставшиеся данные в список
 								result.insert(result.end(), outbuff, outbuff + nbytes);
 							// Если все данные уже дешифрованы
@@ -941,9 +953,9 @@ namespace anyks {
 			 * read Метод чтения данных из файлв в базу
 			 * @return результат операции (количество прочитанных байт)
 			 */
-			const int read() noexcept {
+			const uintmax_t read() noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Адрес файла для открытия
 				const string & filename = this->filename();
 				// Если адрес файла получен
@@ -964,18 +976,21 @@ namespace anyks {
 						result = sizeof(count);
 						// Если количество записей больше 0
 						if(count > 0){
+							// Ключ и значение
+							size_t key = 0, val = 0;
 							// Загружаем полученное количество данных
 							for(size_t i = 0; i < count; i++){
-								// Ключ и значение
-								size_t idw = 0, val = 0;
+								// Сбрасываем ключ и значение
+								key = 0;
+								val = 0;
 								// Считываем ключ записи
-								this->ifs.read((char *) &idw, sizeof(idw));
+								this->ifs.read((char *) &key, sizeof(key));
 								// Считываем позицию записи
 								this->ifs.read((char *) &val, sizeof(val));
 								// Смещаем позицию в файле
 								result += (sizeof(size_t) * 2);
 								// Если значение получено, заполняем заголовки ключей
-								if(idw > 0) this->keys.insert({idw, val});
+								if(key > 0) this->keys.insert({key, val});
 							}
 						}
 						// Закрываем файл
@@ -991,9 +1006,9 @@ namespace anyks {
 			 * write Метод записи данных базы в файл
 			 * @return результат операции (количество записанных байт)
 			 */
-			const int write() noexcept {
+			const uintmax_t write() noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Адрес файла для открытия
 				const string & raw = (this->filename() + ".raw");
 				// Если адрес файла получен
@@ -1004,6 +1019,8 @@ namespace anyks {
 					this->ofs.open(this->filename().c_str(), ios::binary);
 					// Если файл открыт
 					if(this->ofs.is_open()){
+						// Полученные ключ и значение
+						size_t key = 0, val = 0;
 						// Получаем количество записей
 						const size_t count = this->keys.size();
 						// Получаем бинарные данные количества ключей
@@ -1017,9 +1034,9 @@ namespace anyks {
 						// Переходим по всему количеству ключей
 						for(auto it = this->keys.cbegin(); it != this->keys.cend(); ++it){
 							// Получаем ключ
-							const size_t key = it->first;
+							key = it->first;
 							// Получаем значение ключа
-							const size_t val = it->second;
+							val = it->second;
 							// Получаем бинарные данные ключа
 							const char * binKey = reinterpret_cast <const char *> (&key);
 							// Получаем бинарные данные значения
@@ -1037,6 +1054,8 @@ namespace anyks {
 						ifstream file(raw.c_str(), ios::binary);
 						// Если файл открыт
 						if(file.is_open()){
+							// Полученный размер данных
+							size_t size = 0;
 							// Создаем буфер для чтения данных
 							char bytes[CHUNKSIZE];
 							// Считываем до тех пор пока все удачно
@@ -1046,7 +1065,7 @@ namespace anyks {
 								// Выполняем чтение данных в буфер
 								file.read(bytes, CHUNKSIZE);
 								// Получаем количество прочитанных данных
-								const size_t size = file.gcount();
+								size = file.gcount();
 								// Выполняем запись в файл
 								this->ofs.write(bytes, size);
 								// Выполняем сброс данных в файл
@@ -1076,9 +1095,9 @@ namespace anyks {
 			 * @return      результат операции (количество записанных байт)
 			 */
 			template <typename Value>
-			const int set(const string & key, const Value value) noexcept {
+			const uintmax_t set(const string & key, const Value value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1101,9 +1120,9 @@ namespace anyks {
 			 * @param encrypt зашифровать данные
 			 * @return        результат операции (количество записанных байт)
 			 */
-			const int set(const string & key, const string & value, const bool encrypt = false) noexcept {
+			const uintmax_t set(const string & key, const string & value, const bool encrypt = false) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty() && !value.empty()){
 					// Получаем идентификатор ключа
@@ -1141,9 +1160,9 @@ namespace anyks {
 			 * @param encrypt зашифровать данные
 			 * @return        результат операции (количество записанных байт)
 			 */
-			const int set(const string & key, const vector <char> & value, const bool encrypt = false) noexcept {
+			const uintmax_t set(const string & key, const vector <char> & value, const bool encrypt = false) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty() && !value.empty()){
 					// Получаем идентификатор ключа
@@ -1185,9 +1204,9 @@ namespace anyks {
 			 * @param encrypt зашифровать данные
 			 * @return        результат операции (количество записанных байт)
 			 */
-			const int set(const string & key, const char * buffer, const size_t size, const bool encrypt = false) noexcept {
+			const uintmax_t set(const string & key, const char * buffer, const size_t size, const bool encrypt = false) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty() && (buffer != nullptr) && (size > 0)){
 					// Получаем идентификатор ключа
@@ -1229,9 +1248,9 @@ namespace anyks {
 			 * @return      результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			const int setValues(const string & key, const Container & value) noexcept {
+			const uintmax_t setValues(const string & key, const Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty() && !value.empty()){
 					// Получаем идентификатор ключа
@@ -1254,9 +1273,9 @@ namespace anyks {
 			 * @return      результат операции (количество записанных байт)
 			 */
 			template <class Container>
-			const int setStrings(const string & key, const Container & value) noexcept {
+			const uintmax_t setStrings(const string & key, const Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty() && !value.empty()){
 					// Получаем идентификатор ключа
@@ -1280,9 +1299,9 @@ namespace anyks {
 			 * @return      результат операции (количество прочитанных байт)
 			 */
 			template <typename Value>
-			const int get(const string & key, Value & value) noexcept {
+			const uintmax_t get(const string & key, Value & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1309,9 +1328,9 @@ namespace anyks {
 			 * @param decrypt расшифровать данные
 			 * @return        результат операции (количество прочитанных байт)
 			 */
-			const int get(const string & key, string & value, const bool decrypt = false) noexcept {
+			const uintmax_t get(const string & key, string & value, const bool decrypt = false) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1359,9 +1378,9 @@ namespace anyks {
 			 * @param decrypt расшифровать данные
 			 * @return        результат операции (количество прочитанных байт)
 			 */
-			const int get(const string & key, vector <char> & value, const bool decrypt = false) noexcept {
+			const uintmax_t get(const string & key, vector <char> & value, const bool decrypt = false) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1423,9 +1442,9 @@ namespace anyks {
 			 * @return      результат операции (количество прочитанных байт)
 			 */
 			template <class Container>
-			const int getValues(const string & key, Container & value) noexcept {
+			const uintmax_t getValues(const string & key, Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1452,9 +1471,9 @@ namespace anyks {
 			 * @return      результат операции (количество прочитанных байт)
 			 */
 			template <class Container>
-			const int getStrings(const string & key, Container & value) noexcept {
+			const uintmax_t getStrings(const string & key, Container & value) noexcept {
 				// Результат работы функции
-				int result = -1;
+				uintmax_t result = 0;
 				// Если ключ передан
 				if(!key.empty()){
 					// Получаем идентификатор ключа
@@ -1481,10 +1500,10 @@ namespace anyks {
 			void clear() noexcept {
 				// Закрываем открытый файл
 				this->close();
+				// Очищаем позицию raw данных
+				this->rawpos = 0;
 				// Очищаем список ключей
 				this->keys.clear();
-				// Очищаем позицию raw данных
-				this->rawpos = -1;
 				// Смещаем указатель начала данных
 				this->address = strlen(HEADER);
 			}
