@@ -61,10 +61,11 @@ namespace anyks {
 				resetUnk,   // Флаг сброса частоты неизвестного слова
 				onlyGood,   // Флаг использования только слов из белого списка
 				allowUnk,   // Флаг разрешаюний использовать токен неизвестного слова
-				allGrams,   // Флаг предписывающий использовать все полученные n-граммы
+				allGrams,   // Флаг предписывающий использовать все полученные N-граммы
 				mixdicts,   // Флаг разрешающий детектировать слова из смешанных словарей
 				lowerCase,  // Флаг предписывающий использовать слова в нижнем регистре
-				confidence, // Флаг разрешающий загружать n-граммы из arpa так-как они есть
+				tokenWords, // Флаг предписывающий включать в N-граммы, только токены соответствующие словам 
+				confidence, // Флаг разрешающий загружать N-граммы из arpa так-как они есть
 				interpolate // Флаг предписывающий выполнять интерполяцию при расчёте частот
 			};
 			// Флаги модификации
@@ -123,7 +124,7 @@ namespace anyks {
 			// Параметры алгоритма сглаживания
 			params_t params;
 			// Флаги параметров
-			bitset <9> options;
+			bitset <10> options;
 			// Список плохих слов
 			set <size_t> badwords;
 			// Список хороших слов
@@ -173,6 +174,7 @@ namespace anyks {
 			 * @return       идентификатор слова
 			 */
 			const size_t getIdw(const wstring & word, const bool check = true) const noexcept;
+		public:
 			/**
 			 * clearShielding Функция удаления экранирования
 			 * @param word  слово в котором следует удалить экранирование
@@ -236,6 +238,7 @@ namespace anyks {
 			 * @return общее количество документов и слов в корпусах при обучении
 			 */
 			const pair <size_t, size_t> getStatistic() const noexcept;
+		public:
 			/**
 			 * getUserTokens Метод извлечения списка пользовательских токенов
 			 * @return список пользовательских токенов
