@@ -230,7 +230,7 @@ const anyks::Alm::ppl_t anyks::Alm1::perplexity(const vector <size_t> & seq) con
 		// Временная последовательность
 		vector <size_t> tmp;
 		// Определяем смещение в последовательности
-		size_t offset1 = 0, offset2 = (count > this->size ? this->size : count);
+		size_t offset1 = 0, offset2 = (count > size_t(this->size) ? this->size : count);
 		// Проверяем разрешено ли неизвестное слово
 		const bool isAllowUnk = (this->frequency({size_t(token_t::unk)}).first != this->zero);
 		/**
@@ -465,7 +465,7 @@ const anyks::Alm::ppl_t anyks::Alm1::perplexity(const vector <size_t> & seq) con
 				// Получаем обрабатываемый текст
 				const wstring & text = this->context(seq, true);
 				// Выводим сообщение отладки - количество слов
-				this->alphabet->log("%s\n", alphabet_t::log_t::info, this->logfile, this->alphabet->convert(text).c_str());
+				this->alphabet->log("%ls\n", alphabet_t::log_t::info, this->logfile, text.c_str());
 				// Переходим по всему списку отладки
 				for(auto & mess : debugMessages){
 					// Выводим основное сообщение отладки
@@ -502,6 +502,178 @@ const anyks::Alm::ppl_t anyks::Alm1::perplexity(const vector <size_t> & seq) con
 	// Выводим результат
 	return result;
 }
+/**
+ * check Метод проверки существования последовательности, с указанным шагом
+ * @param seq  список слов последовательности
+ * @param step размер шага проверки последовательности
+ * @return     результат проверки
+ */
+const bool anyks::Alm1::check(const vector <size_t> & seq, const u_short step) const noexcept {
+	// Результат работы функции
+	bool result = false;
+	// Если последовательность передана
+	if(!seq.empty() && (seq.size() >= size_t(step)) && (this->size >= step) && !this->arpa.empty()){
+		// Временная последовательность
+		vector <size_t> tmp, sequence;
+		// Если последовательность не экранированна
+		if((seq.back() == size_t(token_t::finish)) &&
+		(seq.front() == size_t(token_t::start))) sequence.assign(seq.begin() + 1, seq.end() - 1);
+		else if(seq.back() == size_t(token_t::finish)) sequence.assign(seq.begin(), seq.end() - 1);
+		else if(seq.front() == size_t(token_t::start)) sequence.assign(seq.begin() + 1, seq.end());
+		else sequence.assign(seq.begin(), seq.end());
+		// Если последовательность, до сих пор соответствует
+		if(sequence.size() >= size_t(step)){
+			/**
+			 * checkFn Функция проверки существования последовательности
+			 * @param seq список слов последовательности
+			 * @return    результат проверки
+			 */
+			auto checkFn = [this](const vector <size_t> & seq) noexcept {
+				// Регистры слова в последовательности
+				bool result = false;
+				// Если список последовательностей передан
+				if(!seq.empty() && (this->size > 0)){
+					// Итератор для подсчета длины n-граммы
+					u_short i = 0;
+					// Копируем основную карту
+					arpa_t * obj = &this->arpa;
+					// Переходим по всему объекту
+					for(auto & idw : seq){
+						// Выполняем поиск нашего слова
+						auto it = obj->find(idw);
+						// Если слово найдено
+						if(it != obj->end()){
+							// Получаем блок структуры
+							obj = &it->second;
+							// Если мы дошли до конца
+							result = (i == (seq.size() - 1));
+						// Выходим из цикла
+						} else break;
+						// Если количество n-грамм достигло предела, выходим
+						if((++i) > (this->size - 1)) break;
+					}
+				}
+				// Выводим результат
+				return result;
+			};
+			// Количество переданных последовательностей
+			const size_t count = sequence.size();
+			// Определяем смещение в последовательности
+			size_t offset1 = 0, offset2 = (count > size_t(step) ? (step < 2 ? 2 : step) : count);
+			// Выполняем извлечение данных
+			while(offset2 < (count + 1)){
+				// Получаем первую часть последовательности
+				tmp.assign(sequence.begin() + offset1, sequence.begin() + offset2);
+				// Если последовательность получена
+				if(!tmp.empty()){
+					// Получаем регистр слова
+					result = checkFn(tmp);
+					// Если последовательность не найдена, выходим
+					if(!result) break;
+				// Выходим из цикла
+				} else break;
+				// Увеличиваем смещение
+				offset1++;
+				offset2++;
+			}
+		}
+	}
+	// Выводим результат
+	return result;
+}
+/**
+ * exist Метод проверки существования последовательности
+ * @param seq  список слов последовательности
+ * @param step размер шага проверки последовательности
+ * @return     результат проверки
+ */
+const pair <bool, size_t> anyks::Alm1::exist(const vector <size_t> & seq, const u_short step) const noexcept {
+	// Результат работы функции
+	pair <bool, size_t> result = {false, 0};
+	// Если последовательность передана
+	if(!seq.empty() && (seq.size() >= size_t(step)) && (this->size >= step) && !this->arpa.empty()){
+		// Временная последовательность
+		vector <size_t> sequence;
+		// Если последовательность не экранированна
+		if((seq.back() == size_t(token_t::finish)) &&
+		(seq.front() == size_t(token_t::start))) sequence.assign(seq.begin() + 1, seq.end() - 1);
+		else if(seq.back() == size_t(token_t::finish)) sequence.assign(seq.begin(), seq.end() - 1);
+		else if(seq.front() == size_t(token_t::start)) sequence.assign(seq.begin() + 1, seq.end());
+		else sequence.assign(seq.begin(), seq.end());
+		// Если последовательность, до сих пор соответствует
+		if(sequence.size() >= size_t(step)){
+			/**
+			 * Прототип функции проверки на существование последовательности
+			 * @param начальная позиция итератора в последовательности
+			 * @return результат проверки, сущестования последовательности
+			 */
+			function <const pair <bool, size_t> (u_short)> checkFn;
+			/**
+			 * checkFn Функция проверки на существование последовательности
+			 * @param start начальная позиция итератора в последовательности
+			 * @return      результат проверки, сущестования последовательности
+			 */
+			checkFn = [&checkFn, &sequence, step, this](u_short start) noexcept {
+				// Результат работы функции
+				pair <bool, size_t> result = {false, 0};
+				// Копируем основную карту
+				arpa_t * obj = &this->arpa;
+				// Идентификатор слова и количество слов в последовательности
+				size_t idw = idw_t::NIDW, count = sequence.size();
+				// Получаем конечный элемент
+				const u_short stop = (start + ((count - size_t(start)) >= size_t(step) ? step : count - start));
+				// Переходим по всему объекту
+				for(u_short i = start; i < stop; i++){
+					// Получаем идентификатор слова
+					idw = sequence.at(i);
+					// Если идентификатор токена - валиден
+					if(this->tokenizer->isIdWord(idw)){
+						// Выполняем поиск нашего слова
+						auto it = obj->find(idw);
+						// Если слово найдено
+						if(it != obj->end()){
+							// Получаем блок структуры
+							obj = &it->second;
+							// Если мы дошли до конца
+							result.first = (i == (stop - 1));
+							// Увеличиваем начало следующей итерации
+							if(result.first){
+								// Увеличиваем стартовую позицию
+								start++;
+								// Устанавливаем количество совпадений
+								if(step == stop) result.second = step;
+							}
+						// Выходим из цикла
+						} else break;
+					// Если токен не валиден
+					} else {
+						// Увеличиваем начало следующей итерации
+						start += 2;
+						// Запоминаем, что результат возможем
+						result.first = true;
+						// Выходим из цикла
+						break;
+					}
+				}
+				// Если начало следующей итерации еще возможно
+				if(result.first && (size_t(start) < count)){
+					// Выполняем поиск дальше
+					const auto & res = checkFn(start);
+					// Устанавливаем результат поиска
+					result.first = res.first;
+					// Увеличиваем количество найденных совпадений
+					result.second += res.second;
+				}
+				// Выводим результат проверки
+				return result;
+			};
+			// Выполняем проверку
+			result = checkFn(0);
+		}
+	}
+	// Выводим результат
+	return result;
+}
 /**
  * check Метод проверки существования последовательности
  * @param seq      список слов последовательности
@@ -518,11 +690,11 @@ const pair <bool, size_t> anyks::Alm1::check(const vector <size_t> & seq, const
 		// Если последовательность не экранированна
 		if((seq.back() == size_t(token_t::finish)) &&
 		(seq.front() == size_t(token_t::start))) sequence.assign(seq.begin() + 1, seq.end() - 1);
-		else if(seq.back() == size_t(token_t::finish)) sequence.assign(seq.begin() + 1, seq.end());
-		else if(seq.front() == size_t(token_t::start)) sequence.assign(seq.begin(), seq.end() - 1);
+		else if(seq.back() == size_t(token_t::finish)) sequence.assign(seq.begin(), seq.end() - 1);
+		else if(seq.front() == size_t(token_t::start)) sequence.assign(seq.begin() + 1, seq.end());
 		else sequence.assign(seq.begin(), seq.end());
 		/**
-		 * checkFn Прототип функции проверки существования последовательности
+		 * Прототип функции проверки существования последовательности
 		 * @param  список слов последовательности
 		 * @return результат проверки
 		 */
@@ -572,7 +744,7 @@ const pair <bool, size_t> anyks::Alm1::check(const vector <size_t> & seq, const
 		// Количество переданных последовательностей
 		const size_t count = sequence.size();
 		// Определяем смещение в последовательности
-		size_t offset1 = 0, offset2 = (count > this->size ? this->size : count);
+		size_t offset1 = 0, offset2 = (count > size_t(this->size) ? this->size : count);
 		// Выполняем извлечение данных
 		while(offset2 < (count + 1)){
 			// Получаем первую часть последовательности
@@ -600,6 +772,8 @@ const pair <bool, size_t> anyks::Alm1::check(const vector <size_t> & seq, const
 void anyks::Alm1::setBin(const vector <char> & buffer) const noexcept {
 	// Если буфер передан
 	if(!buffer.empty()){
+		// Полученная последовательность
+		seq_t sequence;
 		// Количество слов в последовательности
 		u_short count = 0;
 		// Смещение в буфере
@@ -608,27 +782,28 @@ void anyks::Alm1::setBin(const vector <char> & buffer) const noexcept {
 		vector <seq_t> seq;
 		// Получаем данные буфера
 		const char * data = buffer.data();
-		// Извлекаем количество слов в последовательности
-		memcpy(&count, data + offset, sizeof(count));
-		// Увеличиваем смещение
-		offset += sizeof(count);
-		// Если последовательность получена
-		if(count > 0){
-			// Полученная последовательность
-			seq_t sequence;
-			// Выделяем память для последовательности
-			seq.resize(count);
-			// Переходим по всем словам последовательности
-			for(u_short i = 0; i < count; i++){
-				// Извлекаем данные слова
-				memcpy(&sequence, data + offset, sizeof(sequence));
-				// Добавляем последовательность в список
-				seq[i] = sequence;
-				// Увеличиваем смещение
-				offset += sizeof(sequence);
+		// Выполняем перебор данных всего буфера
+		while(offset < buffer.size()){
+			// Извлекаем количество слов в последовательности
+			memcpy(&count, data + offset, sizeof(count));
+			// Увеличиваем смещение
+			offset += sizeof(count);
+			// Если последовательность получена
+			if(count > 0){
+				// Очищаем последовательность
+				seq.clear();
+				// Переходим по всем словам последовательности
+				for(u_short i = 0; i < count; i++){
+					// Извлекаем данные слова
+					memcpy(&sequence, data + offset, sizeof(sequence));
+					// Добавляем последовательность в список
+					seq.push_back(sequence);
+					// Увеличиваем смещение
+					offset += sizeof(sequence);
+				}
+				// Если нужно установить исходные данные
+				if(!seq.empty()) this->set(seq);
 			}
-			// Если нужно установить исходные данные
-			this->set(seq);
 		}
 	}
 }
@@ -636,41 +811,51 @@ void anyks::Alm1::setBin(const vector <char> & buffer) const noexcept {
  * getBin Метод извлечения данных arpa в бинарном виде
  * @param callback функция обратного вызова
  */
-void anyks::Alm1::getBin(function <void (const vector <char> &, const u_short)> callback) const noexcept {
+void anyks::Alm1::getBin(function <void (const vector <char> &, const size_t, const u_short)> callback) const noexcept {
 	// Если данные загружены
 	if(!this->arpa.empty()){
 		// Данные последовательности
 		seq_t sequence;
-		// Индекс обработки статуса
-		size_t index = 0;
 		// Собранная последовательность
 		vector <seq_t> seq;
 		// Буфер данных n-граммы
 		vector <char> buffer;
+		// Индекс обработки статуса и количество обработанных N-грамм
+		size_t index = 0, countNgrams = 0;
 		/**
 		 * resultFn Метод формирования результата
+		 * @param index индекс обработанного буфера
+		 * @param seq   список собранной последовательности
 		 */
-		auto resultFn = [&buffer, &seq, &index, &callback, this]() noexcept {
-			// Получаем количество n-грамм в списке
-			u_short count = seq.size();
-			// Получаем бинарные данные количества слов
-			const char * bin = reinterpret_cast <const char *> (&count);
-			// Добавляем в буфер количество слов
-			buffer.insert(buffer.end(), bin, bin + sizeof(count));
-			// Переходим по всему списку последовательности
-			for(auto & item : seq){
-				// Получаем бинарные данные последовательности
-				bin = reinterpret_cast <const char *> (&item);
-				// Добавляем в буфер бинарные данные последовательности
-				buffer.insert(buffer.end(), bin, bin + sizeof(item));
+		auto resultFn = [&buffer, &countNgrams, &callback, this](const size_t index, const vector <seq_t> & seq) noexcept {
+			// Если последовательность не пустая
+			if(!seq.empty()){
+				// Получаем количество n-грамм в списке
+				u_short count = seq.size();
+				// Увеличиваем количество обработанных N-грамм
+				if(count == this->size) countNgrams++;
+				// Получаем бинарные данные количества слов
+				const char * bin = reinterpret_cast <const char *> (&count);
+				// Добавляем в буфер количество слов
+				buffer.insert(buffer.end(), bin, bin + sizeof(count));
+				// Переходим по всему списку последовательности
+				for(auto & item : seq){
+					// Получаем бинарные данные последовательности
+					bin = reinterpret_cast <const char *> (&item);
+					// Добавляем в буфер бинарные данные последовательности
+					buffer.insert(buffer.end(), bin, bin + sizeof(item));
+				}
+				// Если буфер имеет размер в 100Mb
+				if(buffer.size() >= BUFFER_SIZE){
+					// Выводим собранную последовательность
+					callback(buffer, countNgrams, u_short(index / double(this->arpa.size()) * 100.0));
+					// Очищаем полученный буфер n-граммы
+					buffer.clear();
+				}
 			}
-			// Выводим собранную последовательность
-			callback(buffer, u_short(index / double(this->arpa.size()) * 100.0));
-			// Очищаем полученный буфер n-граммы
-			buffer.clear();
 		};
 		/**
-		 * runFn Прототип функции запуска формирования map карты последовательностей
+		 * Прототип функции запуска формирования map карты последовательностей
 		 * @param словарь для извлечения слова с его параметрами
 		 */
 		function <void (const arpa_t *)> runFn;
@@ -679,16 +864,12 @@ void anyks::Alm1::getBin(function <void (const vector <char> &, const u_short)>
 		 * @param ngrams словарь для извлечения слова с его параметрами
 		 */
 		runFn = [&](const arpa_t * ngrams) noexcept {
-			// Идентификатор полученного и добавленного слова
-			size_t idw = idw_t::NIDW, aidw = 0;
 			// Получаем объект данных
 			const arpa_t * obj = (ngrams != nullptr ? ngrams : &this->arpa);
 			// Переходим по всему объекту с данными
 			for(auto & item : * obj){
 				// Увеличиваем индекс если это юниграмма
 				if(ngrams == nullptr) index++;
-				// Запоминаем идентификатор добавленного слова
-				idw = sequence.idw;
 				// Извлекаем основные данные
 				sequence.idw     = item.first;
 				sequence.ups     = item.second.uppers;
@@ -699,20 +880,24 @@ void anyks::Alm1::getBin(function <void (const vector <char> &, const u_short)>
 				// Если еще есть продолжение граммы
 				if(!item.second.empty()) runFn(&item.second);
 				// Иначе выводим то что есть
-				else if(idw != aidw) {
-					// Запоминаем идентификатор добавленного слова
-					aidw = idw;
-					// Выводим результат
-					resultFn();
-				}
+				else resultFn(index, seq);
 				// Удаляем последний элемент в списке
 				seq.pop_back();
 			}
 		};
 		// Запускаем извлечение данных
 		runFn(nullptr);
+		// Если буфер не пустой
+		if(!buffer.empty()){
+			// Выводим собранную последовательность
+			callback(buffer, countNgrams, u_short(index / double(this->arpa.size()) * 100.0));
+			// Очищаем полученный буфер n-граммы
+			buffer.clear();
+			// Освобождаем выделенную память
+			vector <char> ().swap(buffer);
+		}
 	// Выводим пустой результат
-	} else callback({}, 0);
+	} else callback({}, 0, 0);
 }
 /**
  * sentences Метод генерации предложений
@@ -754,7 +939,7 @@ void anyks::Alm1::sentences(function <const bool (const wstring &)> callback) co
 			return true;
 		};
 		/**
-		 * estimateFn Прототип функции оценки собранных последовательностей
+		 * Прототип функции оценки собранных последовательностей
 		 * @param  список собранной последовательности
 		 * @return список собранных последовательностей
 		 */
@@ -832,7 +1017,7 @@ void anyks::Alm1::sentences(function <const bool (const wstring &)> callback) co
 			return result;
 		};
 		/**
-		 * runFn Прототип функции запуска перебора предложения
+		 * Прототип функции запуска перебора предложения
 		 * @param  список собранной последовательности
 		 * @param  контекст в котором нужно собирать данные
 		 * @return флаг продолжения или завершения работы
@@ -899,7 +1084,7 @@ void anyks::Alm1::getUppers(const vector <size_t> & seq, vector <size_t> & upps)
 		if(!isFront) sequence.push_back((size_t) token_t::finish);
 		if(!isBack)  sequence.insert(sequence.begin(), (size_t) token_t::start);
 		/**
-		 * uppersFn Прототип функции извлечения регистров последовательности
+		 * Прототип функции извлечения регистров последовательности
 		 * @param  список слов последовательности
 		 * @return регистры последнего слова последовательности
 		 */
@@ -951,7 +1136,7 @@ void anyks::Alm1::getUppers(const vector <size_t> & seq, vector <size_t> & upps)
 		// Количество переданных последовательностей
 		const size_t count = sequence.size();
 		// Определяем смещение в последовательности
-		size_t offset1 = 0, offset2 = (count > this->size ? this->size : count);
+		size_t offset1 = 0, offset2 = (count > size_t(this->size) ? this->size : count);
 		// Выполняем извлечение данных
 		while(offset2 < (count + 1)){
 			// Получаем первую часть последовательности
@@ -1052,7 +1237,7 @@ void anyks::Alm1::find(const wstring & text, function <void (const wstring &)> c
 			}
 		};
 		/**
-		 * checkFn Прототип функции проверки существования последовательности
+		 * Прототип функции проверки существования последовательности
 		 * @param список слов последовательности
 		 * @param список реальных слов в последовательности
 		 */
@@ -1119,7 +1304,7 @@ void anyks::Alm1::find(const wstring & text, function <void (const wstring &)> c
 				// Количество переданных последовательностей
 				const size_t count = seq.size();
 				// Определяем смещение в последовательности
-				size_t offset1 = 0, offset2 = (count > this->size ? this->size : count);
+				size_t offset1 = 0, offset2 = (count > size_t(this->size) ? this->size : count);
 				// Выполняем извлечение данных
 				while(offset2 < (count + 1)){
 					// Получаем первую часть последовательности
@@ -1184,7 +1369,7 @@ void anyks::Alm1::find(const wstring & text, function <void (const wstring &)> c
 					// Иначе продолжаем дальше
 					else {
 						// Проверяем является ли строка словом
-						const bool isWord = this->event(idw);
+						const bool isWord = !this->tokenizer->isToken(idw);
 						// Если это неизвестное слово
 						if((idw == uid) || (isWord && (this->getWord(idw) == nullptr))) unkFn();
 						// Иначе добавляем слово
@@ -1224,7 +1409,7 @@ const wstring anyks::Alm1::context(const vector <size_t> & seq, const bool nwrd)
 		if(seq.back() != size_t(token_t::finish)) sequence.push_back((size_t) token_t::finish);
 		if(seq.front() != size_t(token_t::start)) sequence.insert(sequence.begin(), (size_t) token_t::start);
 		/**
-		 * uppersFn Прототип функции извлечения регистров последовательности
+		 * Прототип функции извлечения регистров последовательности
 		 * @param  список слов последовательности
 		 * @return регистры последнего слова последовательности
 		 */
@@ -1278,7 +1463,7 @@ const wstring anyks::Alm1::context(const vector <size_t> & seq, const bool nwrd)
 		// Количество переданных последовательностей
 		const size_t count = sequence.size();
 		// Определяем смещение в последовательности
-		size_t offset1 = 0, offset2 = (count > this->size ? this->size : count);
+		size_t offset1 = 0, offset2 = (count > size_t(this->size) ? this->size : count);
 		// Выполняем извлечение данных
 		while(offset2 < (count + 1)){
 			// Получаем первую часть последовательности
